==> monaco-vscode-api-7.1.0.tgz: package/vscode/src/vs/platform/quickinput/browser/quickInputActions.js <==
import { KeyMod as KeyMod$1, KeyCode } from '../../../base/common/keyCodes.js';
import { isMacintosh } from '../../../base/common/platform.js';
import { localizeWithPath } from '../../../nls.js';
import { ContextKeyExpr } from '../../contextkey/common/contextkey.js';
import { InputFocusedContext } from '../../contextkey/common/contextkeys.js';
import { KeybindingsRegistry, KeybindingWeight } from '../../keybinding/common/keybindingsRegistry.js';
import { endOfQuickInputBoxContext, quickInputTypeContextKeyValue, inQuickInputContext } from './quickInput.js';
import { QuickInputType, QuickPickFocus } from '../common/quickInput.js';
import { IQuickInputService } from '../common/quickInput.service.js';
const _moduleId = "vs/platform/quickinput/browser/quickInputActions";
const defaultCommandAndKeybindingRule = {
    weight: KeybindingWeight.WorkbenchContrib,
    when: ( (ContextKeyExpr.and(
         (ContextKeyExpr.equals(quickInputTypeContextKeyValue, QuickInputType.QuickPick)),
        inQuickInputContext
    ))),
    metadata: { description: ( localizeWithPath(
        _moduleId,
        0,
        "Used while in the context of the quick pick. If you change one keybinding for this command, you should change all of the other keybindings (modifier variants) of this command as well."
    )) }
};
function registerQuickPickCommandAndKeybindingRule(rule, options = {}) {
    KeybindingsRegistry.registerCommandAndKeybindingRule({
        ...defaultCommandAndKeybindingRule,
        ...rule,
        secondary: getSecondary(rule.primary, rule.secondary ?? [], options)
    });
}
const ctrlKeyMod = isMacintosh ? KeyMod$1.WinCtrl : KeyMod$1.CtrlCmd;
function getSecondary(primary, secondary, options = {}) {
    if (options.withAltMod) {
        secondary.push(KeyMod$1.Alt + primary);
    }
    if (options.withCtrlMod) {
        secondary.push(ctrlKeyMod + primary);
        if (options.withAltMod) {
            secondary.push(KeyMod$1.Alt + ctrlKeyMod + primary);
        }
    }
    if (options.withCmdMod && isMacintosh) {
        secondary.push(KeyMod$1.CtrlCmd + primary);
        if (options.withCtrlMod) {
            secondary.push(KeyMod$1.CtrlCmd + KeyMod$1.WinCtrl + primary);
        }
        if (options.withAltMod) {
            secondary.push(KeyMod$1.CtrlCmd + KeyMod$1.Alt + primary);
            if (options.withCtrlMod) {
                secondary.push(KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyMod$1.WinCtrl + primary);
            }
        }
    }
    return secondary;
}
function focusHandler(focus, focusOnQuickNatigate) {
    return accessor => {
        const currentQuickPick = accessor.get(IQuickInputService).currentQuickInput;
        if (!currentQuickPick) {
            return;
        }
        if (focusOnQuickNatigate && currentQuickPick.quickNavigate) {
            return currentQuickPick.focus(focusOnQuickNatigate);
        }
        return currentQuickPick.focus(focus);
    };
}
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.pageNext', primary: KeyCode.PageDown, handler: focusHandler(QuickPickFocus.NextPage) }, { withAltMod: true, withCtrlMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.pagePrevious', primary: KeyCode.PageUp, handler: focusHandler(QuickPickFocus.PreviousPage) }, { withAltMod: true, withCtrlMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.first', primary: ctrlKeyMod + KeyCode.Home, handler: focusHandler(QuickPickFocus.First) }, { withAltMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.last', primary: ctrlKeyMod + KeyCode.End, handler: focusHandler(QuickPickFocus.Last) }, { withAltMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.next', primary: KeyCode.DownArrow, handler: focusHandler(QuickPickFocus.Next) }, { withCtrlMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.previous', primary: KeyCode.UpArrow, handler: focusHandler(QuickPickFocus.Previous) }, { withCtrlMod: true });
const nextSeparatorFallbackDesc = ( localizeWithPath(
    _moduleId,
    1,
    "If we're in quick access mode, this will navigate to the next item. If we are not in quick access mode, this will navigate to the next separator."
));
const prevSeparatorFallbackDesc = ( localizeWithPath(
    _moduleId,
    2,
    "If we're in quick access mode, this will navigate to the previous item. If we are not in quick access mode, this will navigate to the previous separator."
));
if (isMacintosh) {
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.CtrlCmd + KeyCode.DownArrow,
        handler: focusHandler(QuickPickFocus.NextSeparator, QuickPickFocus.Next),
        metadata: { description: nextSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.DownArrow,
        secondary: [KeyMod$1.CtrlCmd + KeyMod$1.WinCtrl + KeyCode.DownArrow],
        handler: focusHandler(QuickPickFocus.NextSeparator)
    }, { withCtrlMod: true });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.CtrlCmd + KeyCode.UpArrow,
        handler: focusHandler(QuickPickFocus.PreviousSeparator, QuickPickFocus.Previous),
        metadata: { description: prevSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.UpArrow,
        secondary: [KeyMod$1.CtrlCmd + KeyMod$1.WinCtrl + KeyCode.UpArrow],
        handler: focusHandler(QuickPickFocus.PreviousSeparator)
    }, { withCtrlMod: true });
}
else {
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.Alt + KeyCode.DownArrow,
        handler: focusHandler(QuickPickFocus.NextSeparator, QuickPickFocus.Next),
        metadata: { description: nextSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.DownArrow,
        handler: focusHandler(QuickPickFocus.NextSeparator)
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.Alt + KeyCode.UpArrow,
        handler: focusHandler(QuickPickFocus.PreviousSeparator, QuickPickFocus.Previous),
        metadata: { description: prevSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.UpArrow,
        handler: focusHandler(QuickPickFocus.PreviousSeparator)
    });
}
registerQuickPickCommandAndKeybindingRule({
    id: 'quickInput.acceptInBackground',
    when: ( (ContextKeyExpr.and(
        defaultCommandAndKeybindingRule.when,
         (ContextKeyExpr.or( (InputFocusedContext.negate()), endOfQuickInputBoxContext))
    ))),
    primary: KeyCode.RightArrow,
    weight: KeybindingWeight.WorkbenchContrib + 50,
    handler: (accessor) => {
        const currentQuickPick = accessor.get(IQuickInputService).currentQuickInput;
        currentQuickPick?.accept(true);
    },
}, { withAltMod: true, withCtrlMod: true, withCmdMod: true });

==> monaco-vscode-api-7.1.1.tgz: package/vscode/src/vs/platform/quickinput/browser/quickInputActions.js <==
import { KeyMod as KeyMod$1, KeyCode } from '../../../base/common/keyCodes.js';
import { isMacintosh } from '../../../base/common/platform.js';
import { localize } from '../../../nls.js';
import { ContextKeyExpr } from '../../contextkey/common/contextkey.js';
import { InputFocusedContext } from '../../contextkey/common/contextkeys.js';
import { KeybindingsRegistry, KeybindingWeight } from '../../keybinding/common/keybindingsRegistry.js';
import { endOfQuickInputBoxContext, quickInputTypeContextKeyValue, inQuickInputContext } from './quickInput.js';
import { QuickInputType, QuickPickFocus } from '../common/quickInput.js';
import { IQuickInputService } from '../common/quickInput.service.js';
const defaultCommandAndKeybindingRule = {
    weight: KeybindingWeight.WorkbenchContrib,
    when: ( (ContextKeyExpr.and(
         (ContextKeyExpr.equals(quickInputTypeContextKeyValue, QuickInputType.QuickPick)),
        inQuickInputContext
    ))),
    metadata: { description: ( localize(
        9854,
        "Used while in the context of the quick pick. If you change one keybinding for this command, you should change all of the other keybindings (modifier variants) of this command as well."
    )) }
};
function registerQuickPickCommandAndKeybindingRule(rule, options = {}) {
    KeybindingsRegistry.registerCommandAndKeybindingRule({
        ...defaultCommandAndKeybindingRule,
        ...rule,
        secondary: getSecondary(rule.primary, rule.secondary ?? [], options)
    });
}
const ctrlKeyMod = isMacintosh ? KeyMod$1.WinCtrl : KeyMod$1.CtrlCmd;
function getSecondary(primary, secondary, options = {}) {
    if (options.withAltMod) {
        secondary.push(KeyMod$1.Alt + primary);
    }
    if (options.withCtrlMod) {
        secondary.push(ctrlKeyMod + primary);
        if (options.withAltMod) {
            secondary.push(KeyMod$1.Alt + ctrlKeyMod + primary);
        }
    }
    if (options.withCmdMod && isMacintosh) {
        secondary.push(KeyMod$1.CtrlCmd + primary);
        if (options.withCtrlMod) {
            secondary.push(KeyMod$1.CtrlCmd + KeyMod$1.WinCtrl + primary);
        }
        if (options.withAltMod) {
            secondary.push(KeyMod$1.CtrlCmd + KeyMod$1.Alt + primary);
            if (options.withCtrlMod) {
                secondary.push(KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyMod$1.WinCtrl + primary);
            }
        }
    }
    return secondary;
}
function focusHandler(focus, focusOnQuickNatigate) {
    return accessor => {
        const currentQuickPick = accessor.get(IQuickInputService).currentQuickInput;
        if (!currentQuickPick) {
            return;
        }
        if (focusOnQuickNatigate && currentQuickPick.quickNavigate) {
            return currentQuickPick.focus(focusOnQuickNatigate);
        }
        return currentQuickPick.focus(focus);
    };
}
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.pageNext', primary: KeyCode.PageDown, handler: focusHandler(QuickPickFocus.NextPage) }, { withAltMod: true, withCtrlMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.pagePrevious', primary: KeyCode.PageUp, handler: focusHandler(QuickPickFocus.PreviousPage) }, { withAltMod: true, withCtrlMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.first', primary: ctrlKeyMod + KeyCode.Home, handler: focusHandler(QuickPickFocus.First) }, { withAltMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.last', primary: ctrlKeyMod + KeyCode.End, handler: focusHandler(QuickPickFocus.Last) }, { withAltMod: true, withCmdMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.next', primary: KeyCode.DownArrow, handler: focusHandler(QuickPickFocus.Next) }, { withCtrlMod: true });
registerQuickPickCommandAndKeybindingRule({ id: 'quickInput.previous', primary: KeyCode.UpArrow, handler: focusHandler(QuickPickFocus.Previous) }, { withCtrlMod: true });
const nextSeparatorFallbackDesc = ( localize(
    9855,
    "If we're in quick access mode, this will navigate to the next item. If we are not in quick access mode, this will navigate to the next separator."
));
const prevSeparatorFallbackDesc = ( localize(
    9856,
    "If we're in quick access mode, this will navigate to the previous item. If we are not in quick access mode, this will navigate to the previous separator."
));
if (isMacintosh) {
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.CtrlCmd + KeyCode.DownArrow,
        handler: focusHandler(QuickPickFocus.NextSeparator, QuickPickFocus.Next),
        metadata: { description: nextSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.DownArrow,
        secondary: [KeyMod$1.CtrlCmd + KeyMod$1.WinCtrl + KeyCode.DownArrow],
        handler: focusHandler(QuickPickFocus.NextSeparator)
    }, { withCtrlMod: true });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.CtrlCmd + KeyCode.UpArrow,
        handler: focusHandler(QuickPickFocus.PreviousSeparator, QuickPickFocus.Previous),
        metadata: { description: prevSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.UpArrow,
        secondary: [KeyMod$1.CtrlCmd + KeyMod$1.WinCtrl + KeyCode.UpArrow],
        handler: focusHandler(QuickPickFocus.PreviousSeparator)
    }, { withCtrlMod: true });
}
else {
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.Alt + KeyCode.DownArrow,
        handler: focusHandler(QuickPickFocus.NextSeparator, QuickPickFocus.Next),
        metadata: { description: nextSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.nextSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.DownArrow,
        handler: focusHandler(QuickPickFocus.NextSeparator)
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparatorWithQuickAccessFallback',
        primary: KeyMod$1.Alt + KeyCode.UpArrow,
        handler: focusHandler(QuickPickFocus.PreviousSeparator, QuickPickFocus.Previous),
        metadata: { description: prevSeparatorFallbackDesc }
    });
    registerQuickPickCommandAndKeybindingRule({
        id: 'quickInput.previousSeparator',
        primary: KeyMod$1.CtrlCmd + KeyMod$1.Alt + KeyCode.UpArrow,
        handler: focusHandler(QuickPickFocus.PreviousSeparator)
    });
}
registerQuickPickCommandAndKeybindingRule({
    id: 'quickInput.acceptInBackground',
    when: ( (ContextKeyExpr.and(
        defaultCommandAndKeybindingRule.when,
         (ContextKeyExpr.or( (InputFocusedContext.negate()), endOfQuickInputBoxContext))
    ))),
    primary: KeyCode.RightArrow,
    weight: KeybindingWeight.WorkbenchContrib + 50,
    handler: (accessor) => {
        const currentQuickPick = accessor.get(IQuickInputService).currentQuickInput;
        currentQuickPick?.accept(true);
    },
}, { withAltMod: true, withCtrlMod: true, withCmdMod: true });
